@@ -84,7 +84,9 @@ class Connector extends EventEmitter {
   }
 
   loaded(name, err, data) {
-    const [lng, ns] = name.split('|');
+    const s = name.split('|');
+    const lng = s[0];
+    const ns = s[1];
 
     if (err) this.emit('failedLoading', lng, ns, err);
 
@@ -177,7 +179,9 @@ class Connector extends EventEmitter {
   }
 
   loadOne(name, prefix = '') {
-    const [lng, ns] = name.split('|');
+    const s = name.split('|');
+    const lng = s[0];
+    const ns = s[1];
 
     this.read(lng, ns, 'read', undefined, undefined, (err, data) => {
       if (err) this.logger.warn(`${prefix}loading namespace ${ns} for language ${lng} failed`, err);
@@ -195,8 +199,8 @@ class Connector extends EventEmitter {
       !this.services.utils.hasLoadedNamespace(namespace)
     ) {
       this.logger.warn(
-        `did not save key "${key}" for namespace "${namespace}" as the namespace was not yet loaded`,
-        'This means something IS WRONG in your application setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!',
+        `did not save key "${key}" as the namespace "${namespace}" was not yet loaded`,
+        'This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!',
       );
       return;
     }
