@@ -44,7 +44,8 @@ class Translator extends EventEmitter {
   }
 
   extractFromKey(key, options) {
-    let nsSeparator = options.nsSeparator || this.options.nsSeparator;
+    let nsSeparator =
+      options.nsSeparator !== undefined ? options.nsSeparator : this.options.nsSeparator;
     if (nsSeparator === undefined) nsSeparator = ':';
 
     const keySeparator =
@@ -52,6 +53,13 @@ class Translator extends EventEmitter {
 
     let namespaces = options.ns || this.options.defaultNS;
     if (nsSeparator && key.indexOf(nsSeparator) > -1) {
+      const m = key.match(this.interpolator.nestingRegexp);
+      if (m && m.length > 0) {
+        return {
+          key,
+          namespaces,
+        };
+      }
       const parts = key.split(nsSeparator);
       if (
         nsSeparator !== keySeparator ||
@@ -68,7 +76,7 @@ class Translator extends EventEmitter {
     };
   }
 
-  translate(keys, options) {
+  translate(keys, options, lastKey) {
     if (typeof options !== 'object' && this.options.overloadTranslationOptionHandler) {
       /* eslint prefer-rest-params: 0 */
       options = this.options.overloadTranslationOptionHandler(arguments);
@@ -156,7 +164,7 @@ class Translator extends EventEmitter {
     ) {
       // array special treatment
       res = res.join(joinArrays);
-      if (res) res = this.extendTranslation(res, keys, options);
+      if (res) res = this.extendTranslation(res, keys, options, lastKey);
     } else {
       // string, empty or null
       let usedDefault = false;
@@ -188,6 +196,13 @@ class Translator extends EventEmitter {
           key,
           updateMissing ? options.defaultValue : res,
         );
+        if (keySeparator) {
+          const fk = this.resolve(key, { ...options, keySeparator: false });
+          if (fk && fk.res)
+            this.logger.warn(
+              'Seems the loaded translations were in flat JSON format instead of nested. Either set keySeparator: false on init or make sure your translations are published in nested format.',
+            );
+        }
 
         let lngs = [];
         const fallbackLngs = this.languageUtils.getFallbackCodes(
@@ -243,7 +258,7 @@ class Translator extends EventEmitter {
       }
 
       // extend
-      res = this.extendTranslation(res, keys, options, resolved);
+      res = this.extendTranslation(res, keys, options, resolved, lastKey);
 
       // append namespace if still key
       if (usedKey && res === key && this.options.appendNamespaceToMissingKey)
@@ -258,7 +273,7 @@ class Translator extends EventEmitter {
     return res;
   }
 
-  extendTranslation(res, key, options, resolved) {
+  extendTranslation(res, key, options, resolved, lastKey) {
     if (this.i18nFormat && this.i18nFormat.parse) {
       res = this.i18nFormat.parse(
         res,
@@ -275,6 +290,15 @@ class Translator extends EventEmitter {
           ...options,
           ...{ interpolation: { ...this.options.interpolation, ...options.interpolation } },
         });
+      const skipOnVariables =
+        (options.interpolation && options.interpolation.skipOnVariables) ||
+        this.options.interpolation.skipOnVariables;
+      let nestBef;
+      if (skipOnVariables) {
+        const nb = res.match(this.interpolator.nestingRegexp);
+        // has nesting aftbeforeer interpolation
+        nestBef = nb && nb.length;
+      }
 
       // interpolate
       let data = options.replace && typeof options.replace !== 'string' ? options.replace : options;
@@ -283,8 +307,26 @@ class Translator extends EventEmitter {
       res = this.interpolator.interpolate(res, data, options.lng || this.language, options);
 
       // nesting
+      if (skipOnVariables) {
+        const na = res.match(this.interpolator.nestingRegexp);
+        // has nesting after interpolation
+        const nestAft = na && na.length;
+        if (nestBef < nestAft) options.nest = false;
+      }
       if (options.nest !== false)
-        res = this.interpolator.nest(res, (...args) => this.translate(...args), options);
+        res = this.interpolator.nest(
+          res,
+          (...args) => {
+            if (lastKey && lastKey[0] === args[0] && !options.context) {
+              this.logger.warn(
+                `It seems you are nesting recursively key: ${args[0]} in key: ${key[0]}`,
+              );
+              return null;
+            }
+            return this.translate(...args, key);
+          },
+          options,
+        );
 
       if (options.interpolation) this.interpolator.reset();
     }
@@ -354,10 +396,10 @@ class Translator extends EventEmitter {
         ) {
           checkedLoadedFor[`${codes[0]}-${ns}`] = true;
           this.logger.warn(
-            `key "${usedKey}" for namespace "${usedNS}" for languages "${codes.join(
+            `key "${usedKey}" for languages "${codes.join(
               ', ',
-            )}" won't get resolved as namespace was not yet loaded`,
-            'This means something IS WRONG in your application setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!',
+            )}" won't get resolved as namespace "${usedNS}" was not yet loaded`,
+            'This means something IS WRONG in your setup. You access the t function before i18next.init / i18next.loadNamespace / i18next.changeLanguage was done. Wait for the callback or Promise to resolve before accessing it!!!',
           );
         }
 
