@@ -109,9 +109,9 @@ describe('i18next', () => {
         it('it should not call saveMissing create on backend if not loaded ns', () => {
           i18n.t('ns1:keyNotFound');
 
-          expect(Logger.entries.warn.length).to.equal(2);
+          expect(Logger.entries.warn.length).to.equal(3);
           expect(Logger.entries.warn[0]).to.equal(
-            'i18next::translator: key "keyNotFound" for namespace "ns1" for languages "en-US, en, dev" won\'t get resolved as namespace was not yet loaded',
+            'i18next::translator: key "keyNotFound" for languages "en-US, en, dev" won\'t get resolved as namespace "ns1" was not yet loaded',
           );
           Logger.reset();
         });
@@ -131,9 +131,9 @@ describe('i18next', () => {
           expect(Backend.created.length).to.equal(0);
           Backend.reset();
 
-          expect(Logger.entries.warn.length).to.equal(1);
-          expect(Logger.entries.warn[0]).to.equal(
-            'i18next::backendConnector: did not save key "keyNotFound" for namespace "ns1" as the namespace was not yet loaded',
+          expect(Logger.entries.warn.length).to.equal(2);
+          expect(Logger.entries.warn[1]).to.equal(
+            'i18next::backendConnector: did not save key "keyNotFound" as the namespace "ns1" was not yet loaded',
           );
           Logger.reset();
         });
