@@ -14,4 +14,7 @@ const mockWithT: WithT = {
 const modules: Modules = { external: [] };
 
 const resourceStore: ResourceStore = i18next.services.resourceStore;
+resourceStore.on('added', console.log);
+resourceStore.off('added', console.log);
+resourceStore.off('added');
 resourceStore.data['en'];
